@@ -11,7 +11,7 @@ use Scalar::Util qw(blessed looks_like_number refaddr);
 
 BEGIN {
 	$match::smart::AUTHORITY = 'cpan:TOBYINK';
-	$match::smart::VERSION   = '0.009';
+	$match::smart::VERSION   = '0.010';
 }
 
 our @ISA       = qw( Exporter::Tiny );
@@ -36,7 +36,8 @@ sub match
 	}
 	
 	$seen ||= {};
-	return refaddr($a)==refaddr($b) if $seen->{refaddr($b)}++;
+	my $refb = refaddr($b);
+	return refaddr($a)==$refb if $refb && $seen->{$refb}++;
 	
 	if (ref($b) eq q(ARRAY))
 	{
@@ -199,7 +200,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2017 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
